@@ -17,7 +17,8 @@ def test_bag_get():
 		"server_store": ["tiddlywebplugins.devstore", { "store_root": STORE_DIR }],
 		"instance_tiddlers": {
 			"myBag": ["%s/bravo/index.recipe" % REPO_DIR]
-		}
+		},
+		"root_dir": ""
 	}
 	env = { "tiddlyweb.config": config }
 	store = Storage(config["server_store"][1], env)
@@ -39,7 +40,8 @@ def test_get_bag_from_store():
 		"server_store": ["tiddlywebplugins.devstore", { "store_root": STORE_DIR }],
 		"instance_tiddlers": {
 			"myBag": ["%s/alpha/index.recipe" % REPO_DIR]
-		}
+		},
+		"root_dir": ""
 	}
 	env = { "tiddlyweb.config": config }
 	store = Store(config["server_store"][0], config["server_store"][1], env)
@@ -51,4 +53,4 @@ def test_get_bag_from_store():
 
 	actual = [tiddler.title for tiddler in bag.list_tiddlers()]
 	expected = ["SiteTitle", "foo", "lorem"]
-	assert actual == expected
+	assert sorted(actual) == sorted(expected)
