@@ -17,14 +17,15 @@ def test_list_bags():
 		"instance_tiddlers": {
 			"alpha": ["%s/alpha/index.recipe" % REPO_DIR],
 			"bravo": ["%s/bravo/index.recipe" % REPO_DIR]
-		}
+		},
+		"root_dir": ""
 	}
 	env = { "tiddlyweb.config": config }
 	store = Storage(config["server_store"][1], env)
 
 	actual = [bag.name for bag in store.list_bags()]
 	expected = ["bravo", "alpha"]
-	assert actual == expected
+	assert sorted(actual) == sorted(expected)
 
 
 def test_list_bags_in_store():
@@ -35,11 +36,12 @@ def test_list_bags_in_store():
 		"instance_tiddlers": {
 			"alpha": ["%s/alpha/index.recipe" % REPO_DIR],
 			"bravo": ["%s/bravo/index.recipe" % REPO_DIR]
-		}
+		},
+		"root_dir": ""
 	}
 	env = { "tiddlyweb.config": config }
 	store = Store(config["server_store"][0], config["server_store"][1], env)
 
 	actual = [bag.name for bag in store.list_bags()]
 	expected = ["bravo", "alpha"]
-	assert actual == expected
+	assert sorted(actual) == sorted(expected)
