@@ -25,7 +25,9 @@ import logging
 import simplejson
 
 from shutil import rmtree
+from urllib import unquote as decode
 
+from tiddlyweb import __version__ as TIDDLYWEB_VERSION
 from tiddlyweb.model.tiddler import Tiddler
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.recipe import Recipe
@@ -34,11 +36,14 @@ from tiddlyweb.model.policy import Policy
 from tiddlyweb.store import (NoRecipeError, NoBagError, NoTiddlerError,
 	NoUserError, StoreMethodNotImplemented)
 from tiddlyweb.stores import StorageInterface
+from tiddlyweb.stores.text import _encode_filename as encode
 from tiddlyweb.serializer import Serializer
 from tiddlyweb.util import read_utf8_file, write_utf8_file
 
+from tiddlywebplugins.twimport import url_to_tiddler
 
-__version__ = "0.5.4"
+
+__version__ = "0.7.0"
 
 # XXX: should be class attributes?
 RECIPE_EXT = ".recipe"
@@ -59,6 +64,9 @@ class Store(StorageInterface):
 		config = self.environ["tiddlyweb.config"]
 
 		self._root = store_config["store_root"]
+		if not os.path.isabs(self._root):
+			self._root = os.path.join(config["root_dir"], self._root)
+
 		try:
 			self._index = config["local_instance_tiddlers"]
 		except KeyError:
@@ -108,19 +116,10 @@ class Store(StorageInterface):
 		if not (self._index.get(bag.name, None) or os.path.isdir(bag_path)):
 			raise NoBagError
 
-		if not getattr(bag, "skinny", False):
-			locals = [filename[:-4] for filename in os.listdir(bag_path)
-				if filename.endswith(TIDDLER_EXT)]
-			try:
-				uris = self._index[bag.name]
-				remotes = [_extract_title(uri) for uri in
-					_resolve_references(uris)]
-				titles = set(locals).union(remotes)
-			except KeyError: # non-remote bag
-				titles = locals
-			for title in titles: # TODO: ensure unique titles?
-				tiddler = Tiddler(title, bag.name)
-				bag.add_tiddler(tiddler)
+		if TIDDLYWEB_VERSION.startswith("1.0"):
+			if not (hasattr(bag, "skinny") and bag.skinny):
+				for tiddler in self.list_bag_tiddlers(bag):
+					bag.add_tiddler(tiddler)
 
 		bag.desc = self._read_description(bag_path)
 		bag.policy = self._read_policy(bag_path)
@@ -151,6 +150,8 @@ class Store(StorageInterface):
 				tiddler = self._get_remote_tiddler(tiddler)
 			except KeyError, exc:
 				raise NoTiddlerError(exc)
+		if not tiddler.created:
+			tiddler.created = tiddler.modified
 		tiddler.revision = 1
 		return tiddler
 
@@ -232,13 +233,40 @@ class Store(StorageInterface):
 		return (User(filename[:-5]) for filename in os.listdir(self._root)
 			if filename.endswith(USER_EXT))
 
+	def list_bag_tiddlers(self, bag):
+		bag_path = self._bag_path(bag)
+		locals = [decode(filename[:-4]) for filename in os.listdir(bag_path)
+			if filename.endswith(TIDDLER_EXT)]
+		store = self.environ.get("tiddlyweb.store", self)
+		try:
+			uris = self._index[bag.name]
+			remotes = [_extract_title(uri) for uri in
+					_resolve_references(uris)]
+			titles = set(locals).union(remotes)
+		except KeyError: # non-remote bag
+			titles = locals
+		for title in titles:
+			tiddler = self.tiddler_get(Tiddler(title, bag.name))
+			tiddler.store = store
+			yield tiddler
+
 	def list_tiddler_revisions(self, tiddler):
 		logging.debug("list revisions %s" % tiddler)
 		raise StoreMethodNotImplemented # store is revisionless
 
-	def search(self, search_query):
-		logging.debug("search %s" % search_query)
-		raise StoreMethodNotImplemented
+	def search(self, query):
+		bags = self.list_bags()
+		for bag in bags:
+			for tiddler in self.list_bag_tiddlers(bag):
+				if query in tiddler.bag:
+					yield tiddler
+				if query in tiddler.tags:
+					yield tiddler
+				for field in tiddler.fields:
+					if query in tiddler.fields[field]:
+						yield tiddler
+				if query in tiddler.text:
+					yield tiddler
 
 	def _write_description(self, desc, base_path):
 		desc_path = self._description_path(base_path)
@@ -282,39 +310,24 @@ class Store(StorageInterface):
 		except IndexError, exc:
 			raise NoTiddlerError(exc)
 
-		if uri.endswith(TIDDLER_EXT):
-			tiddler = self._parse_tid(uri, tiddler)
-		elif uri.endswith(".js"):
-			tiddler.bag = tiddler.bag
-			tiddler.tags = ["systemConfig"]
-			tiddler.text = _read_file(uri)
-		else:
-			raise ConfigurationError("could not parse URI: %s" % uri)
+		bag = tiddler.bag # XXX: caching bag attribute hacky/insufficient?
+		tiddler = url_to_tiddler(uri)
+		tiddler.bag = bag
 
 		return tiddler
 
-	def _parse_tid(self, uri, tiddler):
-		"""
-		Populate Tiddler from .tid file
-
-		.tid format is TiddlyWeb text serialization
-		"""
-		contents = _read_file(uri)
-		self.serializer.object = tiddler
-		self.serializer.from_string(contents)
-		return tiddler
-
 	def _recipe_path(self, recipe):
-		return "%s.recipe" % os.path.join(self._root, recipe.name)
+		return "%s.recipe" % os.path.join(self._root, encode(recipe.name))
 
 	def _bag_path(self, bag):
-		return os.path.join(self._root, bag.name)
+		return os.path.join(self._root, encode(bag.name))
 
 	def _tiddler_path(self, tiddler):
-		return "%s.tid" % os.path.join(self._root, tiddler.bag, tiddler.title)
+		return "%s.tid" % os.path.join(self._root, encode(tiddler.bag),
+			encode(tiddler.title))
 
 	def _user_path(self, user):
-		return "%s.user" % os.path.join(self._root, user.usersign)
+		return "%s.user" % os.path.join(self._root, encode(user.usersign))
 
 	def _policy_path(self, base_path):
 		return os.path.join(base_path, "policy")
